## Looking for help?
Contact me by email:
 * amcc@fe.up.pt
 * antonio.mccarneiro@gmail.com
 
 ## Did you found any bug or want to contribute?
 Check the issue page and how to contribute to SymBeam.
 
 ## Where can I learn the theory?
 Here are some very nice introductions on the topics of statics, solid mechanics and bending:
 * F. P. Beer, E. R. Johnston Jr., J. T. Dewolf, and D. F. Mazurek, *Mechanics of Materials*, McGraw-Hill
 * F. P. Beer, E. R. Johnston Jr., D. F. Mazurek, and E. R. Eisenberg *Vector Mechanics for Engineers: Statics*, McGraw-Hill
 * L. S. Srinath, *Advanced Mechanics of Solids*, McGraw-Hill
